==> hp300_1.0.tar: hp300/examples/concepts/truefalse.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Thu 11/Apr/1991")
(component 0 "Context"
 (name "True / False Example")
 (interface
 )
 (implementation
  (trigMode rad)
  (locked no)
  (component 0 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 582 123)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 1 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "FALSE")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 467 375)
     (extent 126 31)
    )
    (active detail)
   )
  )
  (component 2 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "TRUE")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 465 283)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 3 "Junction"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 637 328)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Note"
   (interface
   )
   (implementation
    (component text 3 5
     THREE WAYS TO GENERATE
       "TRUE" and "FALSE"
         TEXT STRINGS.
    )
   )
   (views
    (icon
    )
    (detail
     (origin 353 123)
     (extent 214 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 5 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "A==0")
   )
   (views
    (icon
     (origin 301 308)
     (extent 78 25)
    )
    (detail
     (origin 313 286)
     (extent 64 68)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 6 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 365 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 201 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 25 9
         PURPOSE:  Shows 3 ways to generate "TRUE" and "FALSE" text strings from a number.
         
         USER INPUT REQUIRED:  Adjust the slider to see that all non-zero values are TRUE.
         
         EXPLANATION: Each of the 3 methods illustrates a concept that may not be optimum
               for this simple example, but can be extended for use in more complicated
               programs.  
         
               The task is to evaluate the input number and produce a text string as output
               such that any non-zero input is considered TRUE and zero is considered FALSE.
         
               Method 1 uses the "If/Then" device to branch to the appropriate text constant
               based on the input number.  This method might be of use if additional actions
               are required in addition to generating the output string, since it allows each
               test to begin a different subthread.  The JCT device shows that data, as well
               as control flow, can be combined and passed through to the output display.
         
               Method 2 is the most concise since it relies on the Math Formula box to evaluate
               the "C" language ternary operator "?"; construct.  The expression (A in this case)
               is evaluated and, if true (non-zero), is replaced by the first expression ("TRUE").
               If the expression is False, it is replaced by the second expression ("FALSE").
         
               Method 3 illustrates how an "Get Values" device can have a formula in the sub-
               array field.  In this case "a != 0" is evaluated as 0 (false) or 1(true) and
               accesses the corresponding element of the input Ary.
        )
       )
       (views
        (icon
         (origin 160 205)
         (extent 78 25)
        )
        (detail
         (origin 36 162)
         (extent 848 437)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 170 269)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 78)
       (extent 849 571)
       (panel
        (origin 38 164)
        (extent 845 533)
        (widget 1 icon
         (title off)
         (origin 437 649)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 53 176)
         (extent 816 465)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 397 418)
       (extent 127 25)
      )
      (detail
       (origin 17 160)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 388)
     (extent 110 25)
    )
    (panel
     (origin 11 122)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 135)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 317 362)
       (Point 362 362)
      )
      (connect D2:0 D1:1
       (Point 460 445)
       (Point 460 460)
       (Point 180 460)
       (Point 180 362)
       (Point 198 362)
      )
      (connect D0:1 D2:0
       (Point 413 352)
       (Point 460 352)
       (Point 460 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 7 "Slider"
   (name "Integer Slider")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "Integer Slider")
     (values range -2 2)
     (datum 0)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
    (component detents 1)
   )
   (views
    (icon
    )
    (detail
     (origin 15 264)
     (extent 210 232)
    )
    (active detail)
   )
  )
  (component 8 "Formula"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "(A ? \"TRUE\" : \"FALSE\")")
   )
   (views
    (icon
     (origin 391 468)
     (extent 78 64)
     (iconImage formula.icon)
    )
    (detail
     (origin 359 451)
     (extent 232 58)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 724 461)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 10 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 714 321)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 11 "FromArray"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (input 2
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary[A!=0]")
   )
   (views
    (icon
     (origin 567 608)
     (extent 127 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 413 551)
     (extent 124 158)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 12 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 724 561)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 13 "LiteralConstant"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (numDims 1)
     (size 2)
     (data
      [ "FALSE" "TRUE" ]
     )
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 192 598)
     (extent 157 64)
    )
    (active detail)
   )
  )
  (configuration
   (connect D5:2 D1:0)
   (connect D5:1 D2:0)
   (connect D2:1 D3:1)
   (connect D1:1 D3:2)
   (connect D7:1 D5:1)
   (connect D7:1 D8:1)
   (connect D8:1 D9:1)
   (connect D3:1 D10:1)
   (connect D13:1 D11:1)
   (connect D7:1 D11:2)
   (connect D11:1 D12:1)
   (connect D7:1 D13:0)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 993 648)
   (configuration
    (connect D5:2 D1:0
     (Point 429 340)
     (Point 440 340)
     (Point 440 330)
     (Point 530 330)
     (Point 530 342)
    )
    (connect D5:1 D2:0
     (Point 429 300)
     (Point 440 300)
     (Point 440 230)
     (Point 530 230)
     (Point 530 250)
    )
    (connect D2:1 D3:1
     (Point 597 300)
     (Point 620 300)
     (Point 620 330)
     (Point 634 330)
    )
    (connect D1:1 D3:2
     (Point 595 390)
     (Point 620 390)
     (Point 620 350)
     (Point 634 350)
    )
    (connect D7:1 D5:1
     (Point 227 380)
     (Point 250 380)
     (Point 250 320)
     (Point 270 320)
    )
    (connect D7:1 D8:1
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 316 480)
    )
    (connect D8:1 D9:1
     (Point 663 480)
     (Point 721 480)
    )
    (connect D3:1 D10:1
     (Point 685 340)
     (Point 711 340)
    )
    (connect D13:1 D11:1
     (Point 351 630)
     (Point 360 630)
     (Point 360 590)
     (Point 370 590)
    )
    (connect D7:1 D11:2
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 250 480)
     (Point 250 520)
     (Point 170 520)
     (Point 170 680)
     (Point 350 680)
     (Point 350 670)
     (Point 370 670)
    )
    (connect D11:1 D12:1
     (Point 629 570)
     (Point 650 570)
     (Point 650 580)
     (Point 721 580)
    )
    (connect D7:1 D13:0
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 270 480)
     (Point 270 565)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.4.tar: hp300/examples/concepts/truefalse.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Thu 02/May/1991")
(component 0 "Context"
 (name "True / False Example")
 (interface
 )
 (implementation
  (trigMode rad)
  (locked no)
  (component 0 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 582 123)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 1 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "FALSE")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 467 375)
     (extent 126 31)
    )
    (active detail)
   )
  )
  (component 2 "LiteralConstant"
   (name "Text")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (datum "TRUE")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 465 283)
     (extent 130 34)
    )
    (active detail)
   )
  )
  (component 3 "Junction"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 637 328)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Note"
   (interface
   )
   (implementation
    (component text 3 5
     THREE WAYS TO GENERATE
       "TRUE" and "FALSE"
         TEXT STRINGS.
    )
   )
   (views
    (icon
    )
    (detail
     (origin 353 123)
     (extent 214 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 5 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "A")
   )
   (views
    (icon
     (origin 301 308)
     (extent 78 25)
    )
    (detail
     (origin 313 286)
     (extent 64 68)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 6 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 365 350)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 201 343)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 25 9
         PURPOSE:  Shows 3 ways to generate "TRUE" and "FALSE" text strings from a number.
         
         USER INPUT REQUIRED:  Adjust the slider to see that all non-zero values are TRUE.
         
         EXPLANATION: Each of the 3 methods illustrates a concept that may not be optimum
               for this simple example, but can be extended for use in more complicated
               programs.  
         
               The task is to evaluate the input number and produce a text string as output
               such that any non-zero input is considered TRUE and zero is considered FALSE.
         
               Method 1 uses the "If/Then" device to branch to the appropriate text constant
               based on the input number.  This method might be of use if additional actions
               are required in addition to generating the output string, since it allows each
               test to begin a different subthread.  The JCT device shows that data, as well
               as control flow, can be combined and passed through to the output display.
         
               Method 2 is the most concise since it relies on the Math Formula box to evaluate
               the "C" language ternary operator "?"; construct.  The expression (A in this case)
               is evaluated and, if true (non-zero), is replaced by the first expression ("TRUE").
               If the expression is False, it is replaced by the second expression ("FALSE").
         
               Method 3 illustrates how an "Get Values" device can have a formula in the sub-
               array field.  In this case "a != 0" is evaluated as 0 (false) or 1(true) and
               accesses the corresponding element of the input Ary.
        )
       )
       (views
        (icon
         (origin 160 205)
         (extent 78 25)
        )
        (detail
         (origin 36 162)
         (extent 848 437)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 170 269)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 78)
       (extent 849 571)
       (panel
        (origin 38 164)
        (extent 845 533)
        (widget 1 icon
         (title off)
         (origin 437 649)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 53 176)
         (extent 816 465)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 397 418)
       (extent 127 25)
      )
      (detail
       (origin 17 160)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 388)
     (extent 110 25)
    )
    (panel
     (origin 11 122)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 135)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 317 362)
       (Point 362 362)
      )
      (connect D2:0 D1:1
       (Point 460 445)
       (Point 460 460)
       (Point 180 460)
       (Point 180 362)
       (Point 198 362)
      )
      (connect D0:1 D2:0
       (Point 413 352)
       (Point 460 352)
       (Point 460 415)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (component 7 "Slider"
   (name "Integer Slider")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "Integer Slider")
     (values range -2 2)
     (datum 0)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
    (component detents 1)
   )
   (views
    (icon
    )
    (detail
     (origin 15 264)
     (extent 210 232)
    )
    (active detail)
   )
  )
  (component 8 "Formula"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "(A ? \"TRUE\" : \"FALSE\")")
   )
   (views
    (icon
     (origin 391 468)
     (extent 78 64)
     (iconImage formula.icon)
    )
    (detail
     (origin 359 451)
     (extent 232 58)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 724 461)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 10 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 714 321)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 11 "FromArray"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (input 2
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary[A!=0]")
   )
   (views
    (icon
     (origin 567 608)
     (extent 127 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 413 551)
     (extent 124 158)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 12 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 724 561)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 13 "LiteralConstant"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text")
     (numDims 1)
     (size 2)
     (data
      [ "FALSE" "TRUE" ]
     )
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (datum "")
    )
   )
   (views
    (icon
    )
    (detail
     (origin 192 598)
     (extent 157 64)
    )
    (active detail)
   )
  )
  (configuration
   (connect D5:2 D1:0)
   (connect D5:1 D2:0)
   (connect D2:1 D3:1)
   (connect D1:1 D3:2)
   (connect D7:1 D5:1)
   (connect D7:1 D8:1)
   (connect D8:1 D9:1)
   (connect D3:1 D10:1)
   (connect D13:1 D11:1)
   (connect D7:1 D11:2)
   (connect D11:1 D12:1)
   (connect D7:1 D13:0)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1043 828)
   (configuration
    (connect D5:2 D1:0
     (Point 429 340)
     (Point 440 340)
     (Point 440 330)
     (Point 530 330)
     (Point 530 342)
    )
    (connect D5:1 D2:0
     (Point 429 300)
     (Point 440 300)
     (Point 440 230)
     (Point 530 230)
     (Point 530 250)
    )
    (connect D2:1 D3:1
     (Point 597 300)
     (Point 620 300)
     (Point 620 330)
     (Point 634 330)
    )
    (connect D1:1 D3:2
     (Point 595 390)
     (Point 620 390)
     (Point 620 350)
     (Point 634 350)
    )
    (connect D7:1 D5:1
     (Point 227 380)
     (Point 250 380)
     (Point 250 320)
     (Point 270 320)
    )
    (connect D7:1 D8:1
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 316 480)
    )
    (connect D8:1 D9:1
     (Point 663 480)
     (Point 721 480)
    )
    (connect D3:1 D10:1
     (Point 685 340)
     (Point 711 340)
    )
    (connect D13:1 D11:1
     (Point 351 630)
     (Point 360 630)
     (Point 360 590)
     (Point 370 590)
    )
    (connect D7:1 D11:2
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 250 480)
     (Point 250 520)
     (Point 170 520)
     (Point 170 680)
     (Point 350 680)
     (Point 350 670)
     (Point 370 670)
    )
    (connect D11:1 D12:1
     (Point 629 570)
     (Point 650 570)
     (Point 650 580)
     (Point 721 580)
    )
    (connect D7:1 D13:0
     (Point 227 380)
     (Point 260 380)
     (Point 260 480)
     (Point 270 480)
     (Point 270 565)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
